@@ -1,6 +1,6 @@
 import pytest
 
-from pynavio.mlflow import ARTIFACTS, register_example_request
+import pynavio
 
 
 @pytest.mark.parametrize(
@@ -10,17 +10,17 @@ from pynavio.mlflow import ARTIFACTS, register_example_request
         (dict()),
         # artifacts is set, but does not contain example_request
         ({
-            ARTIFACTS: {
+            pynavio.mlflow.ARTIFACTS: {
                 'model_path': "a_path"
             }
         }),
         # artifacts is set, example_request file path does not exist
         ({
-            ARTIFACTS: {
+            pynavio.mlflow.ARTIFACTS: {
                 'example_request': "non_existent_path"
             }
         })
     ])
-def testregister_example_request_negative(args, tmpdir):
+def test_register_example_request_negative(args, tmpdir):
     with pytest.raises(AssertionError):
-        register_example_request(tmpdir, **args)
+        pynavio.mlflow.register_example_request(tmpdir, **args)
